import { jsx as _jsx } from "react/jsx-runtime";
import { AbsoluteCenter, CircularProgress, } from '@chakra-ui/react';
/**
 * Default: `48px`
 *
 * Not themable at present, pass overrides in px or theme sizing scale
 */
const defaultSize = '48px';
/**
 * Add 6px clearance via padding to prevent jitter in tight spaces caused
 * by the rotation of the CircularProgress.
 */
const clearanceSx = {
    padding: '6px',
};
/** neutralizes the AbsoluteCenter styles  */
const inlineSx = {
    position: 'relative',
    display: 'inline',
    left: 'auto',
    top: 'auto',
    transform: 'initial',
    // add a little breathing space
    marginLeft: 2,
};
/**
 * Displays a spinner centered in the available space.
 *
 * Style the `AbsoluteCenter` container by passing `containerSx`;
 * any other props will be passed directly to `CircularProgress`.
 *
 * https://chakra-ui.com/docs/components/progress/usage#progress-sizes
 */
export const Loading = ({ containerSx = {}, size = defaultSize, inline = false, ...circularProgressProps }) => (_jsx(AbsoluteCenter, { as: inline ? 'span' : undefined, sx: { ...clearanceSx, ...(inline ? inlineSx : {}), ...containerSx }, "data-testid": "Loading", children: _jsx(CircularProgress, { as: inline ? 'span' : undefined, isIndeterminate: true, size: inline ? '4' : size, ...circularProgressProps }) }));
//# sourceMappingURL=Loading.js.map